# MdDocs

Project documentation with Markdown.

---

[![PyPI Version][pypi-v-image]][pypi-v-link]

- View the [MkDocs documentation][mddocs].
- Project [release notes][release-notes].

## Code of Conduct

Everyone interacting in the MkDocs project's codebases, issue trackers, chat
rooms, and mailing lists is expected to follow the [PyPA Code of Conduct].

[pypi-v-image]: https://img.shields.io/pypi/v/mddocs.svg
[pypi-v-link]: https://pypi.python.org/pypi/mddocs

[mddocs]: https://pymddocs.web.app
[release-notes]: https://pymddocs.web.app/about/release-notes/

[PyPA Code of Conduct]: https://www.pypa.io/en/latest/code-of-conduct/
